@@ -33,6 +33,11 @@ class PreferencesDialog(QtGui.QDialog):
 			lambda x: self.ui.browsebutton.setEnabled(not(x)) or \
 					self.ui.driver.setEnabled(not(x)))
 
+		self.connect(self.ui.nologin,
+			QtCore.SIGNAL("stateChanged(int)"),
+			lambda x: self.ui.username.setEnabled(not(x)) or \
+					self.ui.password.setEnabled(not(x)))
+
 	def try_load_from_file(self):
 		if "HOME" in environ:
 			f = path.join(environ["HOME"], ".improviser")
@@ -53,6 +58,11 @@ class PreferencesDialog(QtGui.QDialog):
 								self.ui.browsebutton.setEnabled(False)
 								self.ui.driver.setEnabled(False)
 								self.ui.no_fluidsynth.setChecked(True)
+						elif key == "nologin":
+							if parts[1] == "1":
+								self.ui.username.setEnabled(False)
+								self.ui.password.setEnabled(False)
+								self.ui.nologin.setChecked(True)
 						elif key == "user":
 							self.ui.username.setText(":".join(parts[1:]))
 						elif key == "pass":
@@ -71,6 +81,7 @@ class PreferencesDialog(QtGui.QDialog):
 				fp.write("no_fluidsynth:%d\n" % self.ui.no_fluidsynth.isChecked())
 				fp.write("user:%s\n" % self.ui.username.text())
 				fp.write("pass:%s\n" % self.ui.password.text())
+				fp.write("nologin:%d\n" % self.ui.nologin.isChecked())
 				fp.close()
 			except:
 				pass
